<template>
  <div>
    <el-input placeholder="请选择" :value="name" disabled>
      <el-button slot="append" icon="el-icon-thumb" @click="handleClick"></el-button>
    </el-input>
    <el-dialog title="生产厂商" :visible.sync="open" width="800px" :append-to-body="true" :destroy-on-close="true">
      <manufacturer-list v-if="open" ref="manufacturerRef"></manufacturer-list>
      <div slot="footer" class="dialog-footer">
        <el-button  type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="open = false">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import manufacturerList from "./list";
import { getManufacturer } from "@/api/oa/manufacturer";
/**
 * 生产厂商
 */
export default {
  name: "manufacturerInput",
  components: {
    manufacturerList
  },
  model: {
    prop: 'value',
    event: 'change'
  },
  props: {
    value: {
      type: [Number],
      default: undefined
    }
  },
  data() {
    return {
      open: false,
      name: ''
    }
  },
  created() {
    if (this.value) {
      getManufacturer(this.value).then(response => {
        this.name = response.data.name;
      });
    }
  },
  methods: {
    handleClick() {
      this.open = true;
    },
    submitForm() {
      const row = this.$refs.manufacturerRef.currentRow;
      if (!row) {
        this.$message.warning("请选择一条数据")
        this.buttonLoading = false;
        return;
      }
      this.name = row.name;
      this.open = false;
      this.$emit("change", row.id);
    }
  }
}
</script>

<style scoped>

</style>